close all; clear all; clc;
%% Initializations
X = [0,2*pi];               % Space interval
T = [0,1];                  % Time interval
nu = @(x) 2 - sin(x);       % Diffusion function
f = @(x) 3./(5-4*cos(x));   % Initial condition
alpha = .8;                  % Constant for higher order term

vec = 4:8;                  % Levels for space discretiziation
m = 3;                      % Shift for plotting
sdata = 0;                  % switch for saving figures

%% Preallocation
L = length(vec);
err = cell(L,1);
uc = cell(L,1);                 
xc = cell(L,1);
tc = cell(L,1);

%% Call method and store data
for J = vec
    n = 2^J;
    M = 128;
    N = [n, M];
    [uc{J-m},xc{J-m},tc{J-m}] = spec_vdiffuse(X,T,N,f,nu,alpha);
    sol = solution(xc{J-m},tc{J-m},nu);
    u = uc{J-m};
    for K = 1:length(tc{J-m})
        err{J-m}(K) = norm(sol(:,K) - u(:,K));
    end

end

%% Plot solution and approximation
x = xc{vec(end)-m};
t = tc{vec(end)-m};
gVec = 1:10:M;
tG = tc{vec(end) - m}(gVec);

figure(1)
surf(tG,[x(1:10:end) x(end)],u([(1:10:end) n],gVec));
title('approximation');

%% Time slice plot
dataM  = char('o', 'd','.','s','+','v');
dataC  = char('b', 'm','g','k','r','c');
figure(4)
pgVec = floor([1 M/4 M/2 3*M/4 M]);
for J = 1:5
    plot(x,u(:,pgVec(J)),'color',dataC(J));
    hold on
    plot(x(1:32:end),u(1:32:end,pgVec(J)),'color',dataC(J),'marker',dataM(J),'LineStyle', 'none');
end
for J = 1:5
    p(J) = plot(x(1),u(1,pgVec(J)),'color',dataC(J),'marker',dataM(J),'LineStyle','-');
end
title('Time slices of approximation');
legend(p,'t=0','t=.25','t=.5','t=.75', 't=1')
hold off

%% Spatial Resolution Study
rErr = zeros(3,n);
rErr1 = log(abs((uc{1}(:,end) - uc{2}(1:2:end,end))./(uc{2}(1:2:end,end) - uc{3}(1:4:end,end))));
rErr2 = log(abs((uc{2}(:,end) - uc{3}(1:2:end,end))./(uc{3}(1:2:end,end) - uc{4}(1:4:end,end))));
diff = uc{4}(1:2:end,end) - uc{5}(1:4:end,end);
diff(diff==0) = eps;
rErr3 = log(abs((uc{3}(:,end) - uc{4}(1:2:end,end))./diff));
plot(x(1:16:end),rErr1,'-o');
hold on
plot(x(1:16:end),rErr2(1:2:end),'-dk');
plot(x(1:16:end),rErr3(1:4:end),'-r');
title('Spacial Resolution study at final time')
legend('Initial mesh size = 16', '32', '64')
xlabel('x-axis')
ylabel('exponent')