function sol = solution(x,t,nu)
% Computes the solution to the equation up to 400 modes
%       u_t + u_x  = (nu(x)u_x)_x, t > 0 and a < x < b
%       u(0,x) = f(x),  u(a,x) = u(t,b)
%
%INPUT
%   x = Spacce decomposition
%   t = time decomposition
%   nu = Diffusion coefficent 
%
%OUTPUT
%   sol = analytical solution
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initializations
m = length(t);
n = length(x);
A = -200:200;

%% Analytical solution
soln = @(x,t) sum(2.^(-abs(A)).*exp(1i.*A*(x-t)-nu(x).*A.^2*t));

%% Evaluate solution
sol = zeros(n,m);
for K = 1:n
    for J = 1:m
        sol(K,J) = real(soln(x(K),t(J)));
    end
end

